summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorIsaku Yamahata <yamahata@valinux.co.jp>2011-06-15 22:58:22 +0900
committerIsaku Yamahata <yamahata@valinux.co.jp>2011-06-15 22:58:22 +0900
commitb0fdb4a2326f6e7c92bba80e6b80857ba2a61612 (patch)
tree91283d5e3e9f16d81b46aa34db2db7f23fbbe96a
parentb3af5e4d5a623cf10828f4724f29dd4475120b70 (diff)
typo
-rw-r--r--nova/api/ec2/cloud.py10
-rw-r--r--nova/compute/api.py4
-rw-r--r--nova/compute/manager.py12
-rw-r--r--nova/db/api.py2
-rw-r--r--nova/db/sqlalchemy/models.py4
-rw-r--r--nova/tests/test_cloud.py2
6 files changed, 18 insertions, 16 deletions
diff --git a/nova/compute/api.py b/nova/compute/api.py
index 3b3bea41b..66edf9faa 100644
--- a/nova/compute/api.py
+++ b/nova/compute/api.py
@@ -445,7 +445,7 @@ class API(base.Base):
@scheduler_api.reroute_compute("stop")
def stop(self, context, instance_id):
- """Stop an instnace."""
+ """Stop an instance."""
LOG.debug(_("Going to try to stop %s"), instance_id)
instance = self._get_instance(context, instance_id, 'stopping')
@@ -464,7 +464,7 @@ class API(base.Base):
instance_id, host)
def start(self, context, instance_id):
- """Start an instnace."""
+ """Start an instance."""
LOG.debug(_("Going to try to start %s"), instance_id)
instance = self._get_instance(context, instance_id, 'starting')
if instance['state_description'] != 'stopped':
diff --git a/nova/compute/manager.py b/nova/compute/manager.py
index 128144942..2e130110a 100644
--- a/nova/compute/manager.py
+++ b/nova/compute/manager.py
@@ -238,8 +238,8 @@ class ComputeManager(manager.SchedulerDependentManager):
# TODO(yamahata): default name and description
vol = volume_api.create(context, bdm['volume_size'],
bdm['snapshot_id'], '', '')
- # TODO(yamahata): creatning volume simulteneously
- # reduce creation time?
+ # TODO(yamahata): creating volume simultaneously
+ # reduces creation time?
volume_api.wait_creation(context, vol['id'])
self.db.block_device_mapping_update(
context, bdm['id'], {'volume_id': vol['id']})
@@ -258,11 +258,11 @@ class ComputeManager(manager.SchedulerDependentManager):
'mount_device':
bdm['device_name']})
elif bdm['virtual_name'] is not None:
- # TODO(yamahata)
+ # TODO(yamahata): ephemeral/swap device support
LOG.debug(_('block_device_mapping: '
'ephemeral device is not supported yet'))
else:
- # TODO(yamahata)
+ # TODO(yamahata): NoDevice support
assert bdm['no_device']
LOG.debug(_('block_device_mapping: '
'no device is not supported yet'))
@@ -414,7 +414,7 @@ class ComputeManager(manager.SchedulerDependentManager):
def stop_instance(self, context, instance_id):
"""Stopping an instance on this host."""
self._shutdown_instance(context, instance_id, 'Stopping')
- # instance state will be updated to stopped by _poll_istance_states()
+ # instance state will be updated to stopped by _poll_instance_states()
@exception.wrap_exception
@checks_instance_lock
@@ -887,7 +887,7 @@ class ComputeManager(manager.SchedulerDependentManager):
return self.driver.get_vnc_console(instance_ref)
def _attach_volume_boot(self, context, instance_id, volume_id, mountpoint):
- """Attach a volume to an instnace at boot time. So actual attach
+ """Attach a volume to an instance at boot time. So actual attach
is done by instance creation"""
# TODO(yamahata):
diff --git a/nova/db/api.py b/nova/db/api.py
index 215fa5009..3f5e9a54a 100644
--- a/nova/db/api.py
+++ b/nova/db/api.py
@@ -934,7 +934,7 @@ def block_device_mapping_update(context, bdm_id, values):
return IMPL.block_device_mapping_update(context, bdm_id, values)
def block_device_mapping_get_all_by_instance(context, instance_id):
- """Get all block device mapping blonging to a instance"""
+ """Get all block device mapping belonging to a instance"""
return IMPL.block_device_mapping_get_all_by_instance(context, instance_id)
diff --git a/nova/db/sqlalchemy/models.py b/nova/db/sqlalchemy/models.py
index a74db811f..0c3ec40c7 100644
--- a/nova/db/sqlalchemy/models.py
+++ b/nova/db/sqlalchemy/models.py
@@ -371,7 +371,7 @@ class BlockDeviceMapping(BASE, NovaBase):
'False)')
device_name = Column(String(255), nullable=False)
- # default=False for compatilibity of the existing code.
+ # default=False for compatibility of the existing code.
# With EC2 API,
# default True for ami specified device.
# default False for created with other timing.
@@ -391,7 +391,7 @@ class BlockDeviceMapping(BASE, NovaBase):
foreign_keys=volume_id)
volume_size = Column(Integer, nullable=True)
- # for no device to supress devices.
+ # for no device to suppress devices.
no_device = Column(Boolean, nullable=True)
diff --git a/nova/tests/test_cloud.py b/nova/tests/test_cloud.py
index c9b75f966..1e8b8e846 100644
--- a/nova/tests/test_cloud.py
+++ b/nova/tests/test_cloud.py
@@ -535,7 +535,7 @@ class CloudTestCase(test.TestCase):
self._wait_for_state(elevated, instance_id, is_deleted)
def test_stop_start_instance(self):
- """Makes sure stop/start instnace works"""
+ """Makes sure stop/start instance works"""
# enforce periodic tasks run in short time to avoid wait for 60s.
self._restart_compute_service(periodic_interval=0.3)
diff --git a/nova/api/ec2/cloud.py b/nova/api/ec2/cloud.py
index cff459cad..637ea46d4 100644
--- a/nova/api/ec2/cloud.py
+++ b/nova/api/ec2/cloud.py
@@ -949,14 +949,16 @@ class CloudController(object):
return True
def stop_instances(self, context, instance_id, **kwargs):
- """Stop each instance in instace_id"""
- LOG.debug(_("Going to stop instnces"))
+ """Stop each instances in instance_id.
+ Here instance_id is a list of instance ids"""
+ LOG.debug(_("Going to stop instances"))
self._do_instances(self.compute_api.stop, context, instance_id)
return True
def start_instances(self, context, instance_id, **kwargs):
- """Start each instance in instace_id"""
- LOG.debug(_("Going to start instnces"))
+ """Start each instances in instance_id.
+ Here instance_id is a list of instance ids"""
+ LOG.debug(_("Going to start instances"))
self._do_instances(self.compute_api.start, context, instance_id)
return True